@@ -12,14 +12,22 @@
  #  Copyright   : David Tschumperle
  #                ( http://tschumperle.users.greyc.fr/ )
  #
- #  License     : CeCILL v2.0
- #                ( http://www.cecill.info/licences/Licence_CeCILL_V2-en.html )
+ #  Licenses    : This file is 'dual-licensed', you have to choose one
+ #                of the two licenses below to apply.
  #
- #  This software is governed by the CeCILL  license under French law and
- #  abiding by the rules of distribution of free software.  You can  use,
- #  modify and/ or redistribute the software under the terms of the CeCILL
- #  license as circulated by CEA, CNRS and INRIA at the following URL
- #  "http://www.cecill.info".
+ #                CeCILL-C
+ #                The CeCILL-C license is close to the GNU LGPL.
+ #                ( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
+ #
+ #            or  CeCILL v2.1
+ #                The CeCILL license is compatible with the GNU GPL.
+ #                ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
+ #
+ #  This software is governed either by the CeCILL or the CeCILL-C license
+ #  under French law and abiding by the rules of distribution of free software.
+ #  You can  use, modify and or redistribute the software under the terms of
+ #  the CeCILL or CeCILL-C licenses as circulated by CEA, CNRS and INRIA
+ #  at the following URL: "http://www.cecill.info".
  #
  #  As a counterpart to the access to the source code and  rights to copy,
  #  modify and redistribute granted by the license, users are provided only
@@ -39,12 +47,12 @@
  #  same conditions as regards security.
  #
  #  The fact that you are presently reading this means that you have had
- #  knowledge of the CeCILL license and that you accept its terms.
+ #  knowledge of the CeCILL and CeCILL-C licenses and that you accept its terms.
  #
 */
 
 #ifndef gmic_version
-#define gmic_version 218
+#define gmic_version 223
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -141,12 +149,6 @@ namespace cimg_library {
 
 #else // #ifndef gmic_build
 
-#ifdef __GNUC__
-#if defined(__FAST_MATH__)
-#error Using the -ffast-math CFLAG is known to lead to important issues in libgmic. Please disable it to compile.
-#endif
-#endif
-
 // Define private functions, used to compile libgmic.
 //---------------------------------------------------
 
@@ -378,6 +380,7 @@ struct gmic {
   static gmic_image<int> builtin_commands_inds;
   static gmic_image<char> stdlib;
   static gmic_list<void*> list_p_is_abort;
+  static bool is_display_available;
 
   gmic_list<char> *const commands, *const commands_names, *const commands_has_arguments,
     *const _variables, *const _variables_names, **const variables, **const variables_names,
